<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'ElementorDeps\\DI\\Annotation\\Inject' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Annotation/Inject.php',
    'ElementorDeps\\DI\\Annotation\\Injectable' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Annotation/Injectable.php',
    'ElementorDeps\\DI\\CompiledContainer' => $baseDir . '/vendor_prefixed/php-di/php-di/src/CompiledContainer.php',
    'ElementorDeps\\DI\\Compiler\\Compiler' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Compiler/Compiler.php',
    'ElementorDeps\\DI\\Compiler\\ObjectCreationCompiler' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Compiler/ObjectCreationCompiler.php',
    'ElementorDeps\\DI\\Compiler\\RequestedEntryHolder' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Compiler/RequestedEntryHolder.php',
    'ElementorDeps\\DI\\Container' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Container.php',
    'ElementorDeps\\DI\\ContainerBuilder' => $baseDir . '/vendor_prefixed/php-di/php-di/src/ContainerBuilder.php',
    'ElementorDeps\\DI\\Definition\\ArrayDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/ArrayDefinition.php',
    'ElementorDeps\\DI\\Definition\\ArrayDefinitionExtension' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/ArrayDefinitionExtension.php',
    'ElementorDeps\\DI\\Definition\\AutowireDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/AutowireDefinition.php',
    'ElementorDeps\\DI\\Definition\\DecoratorDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/DecoratorDefinition.php',
    'ElementorDeps\\DI\\Definition\\Definition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Definition.php',
    'ElementorDeps\\DI\\Definition\\Dumper\\ObjectDefinitionDumper' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Dumper/ObjectDefinitionDumper.php',
    'ElementorDeps\\DI\\Definition\\EnvironmentVariableDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/EnvironmentVariableDefinition.php',
    'ElementorDeps\\DI\\Definition\\Exception\\InvalidAnnotation' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Exception/InvalidAnnotation.php',
    'ElementorDeps\\DI\\Definition\\Exception\\InvalidDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Exception/InvalidDefinition.php',
    'ElementorDeps\\DI\\Definition\\ExtendsPreviousDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/ExtendsPreviousDefinition.php',
    'ElementorDeps\\DI\\Definition\\FactoryDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/FactoryDefinition.php',
    'ElementorDeps\\DI\\Definition\\Helper\\AutowireDefinitionHelper' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Helper/AutowireDefinitionHelper.php',
    'ElementorDeps\\DI\\Definition\\Helper\\CreateDefinitionHelper' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Helper/CreateDefinitionHelper.php',
    'ElementorDeps\\DI\\Definition\\Helper\\DefinitionHelper' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Helper/DefinitionHelper.php',
    'ElementorDeps\\DI\\Definition\\Helper\\FactoryDefinitionHelper' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Helper/FactoryDefinitionHelper.php',
    'ElementorDeps\\DI\\Definition\\InstanceDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/InstanceDefinition.php',
    'ElementorDeps\\DI\\Definition\\ObjectDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/ObjectDefinition.php',
    'ElementorDeps\\DI\\Definition\\ObjectDefinition\\MethodInjection' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/ObjectDefinition/MethodInjection.php',
    'ElementorDeps\\DI\\Definition\\ObjectDefinition\\PropertyInjection' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/ObjectDefinition/PropertyInjection.php',
    'ElementorDeps\\DI\\Definition\\Reference' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Reference.php',
    'ElementorDeps\\DI\\Definition\\Resolver\\ArrayResolver' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Resolver/ArrayResolver.php',
    'ElementorDeps\\DI\\Definition\\Resolver\\DecoratorResolver' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Resolver/DecoratorResolver.php',
    'ElementorDeps\\DI\\Definition\\Resolver\\DefinitionResolver' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Resolver/DefinitionResolver.php',
    'ElementorDeps\\DI\\Definition\\Resolver\\EnvironmentVariableResolver' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Resolver/EnvironmentVariableResolver.php',
    'ElementorDeps\\DI\\Definition\\Resolver\\FactoryResolver' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Resolver/FactoryResolver.php',
    'ElementorDeps\\DI\\Definition\\Resolver\\InstanceInjector' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Resolver/InstanceInjector.php',
    'ElementorDeps\\DI\\Definition\\Resolver\\ObjectCreator' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Resolver/ObjectCreator.php',
    'ElementorDeps\\DI\\Definition\\Resolver\\ParameterResolver' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Resolver/ParameterResolver.php',
    'ElementorDeps\\DI\\Definition\\Resolver\\ResolverDispatcher' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Resolver/ResolverDispatcher.php',
    'ElementorDeps\\DI\\Definition\\SelfResolvingDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/SelfResolvingDefinition.php',
    'ElementorDeps\\DI\\Definition\\Source\\AnnotationBasedAutowiring' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Source/AnnotationBasedAutowiring.php',
    'ElementorDeps\\DI\\Definition\\Source\\Autowiring' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Source/Autowiring.php',
    'ElementorDeps\\DI\\Definition\\Source\\DefinitionArray' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Source/DefinitionArray.php',
    'ElementorDeps\\DI\\Definition\\Source\\DefinitionFile' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Source/DefinitionFile.php',
    'ElementorDeps\\DI\\Definition\\Source\\DefinitionNormalizer' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Source/DefinitionNormalizer.php',
    'ElementorDeps\\DI\\Definition\\Source\\DefinitionSource' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Source/DefinitionSource.php',
    'ElementorDeps\\DI\\Definition\\Source\\MutableDefinitionSource' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Source/MutableDefinitionSource.php',
    'ElementorDeps\\DI\\Definition\\Source\\NoAutowiring' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Source/NoAutowiring.php',
    'ElementorDeps\\DI\\Definition\\Source\\ReflectionBasedAutowiring' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Source/ReflectionBasedAutowiring.php',
    'ElementorDeps\\DI\\Definition\\Source\\SourceCache' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Source/SourceCache.php',
    'ElementorDeps\\DI\\Definition\\Source\\SourceChain' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/Source/SourceChain.php',
    'ElementorDeps\\DI\\Definition\\StringDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/StringDefinition.php',
    'ElementorDeps\\DI\\Definition\\ValueDefinition' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Definition/ValueDefinition.php',
    'ElementorDeps\\DI\\DependencyException' => $baseDir . '/vendor_prefixed/php-di/php-di/src/DependencyException.php',
    'ElementorDeps\\DI\\FactoryInterface' => $baseDir . '/vendor_prefixed/php-di/php-di/src/FactoryInterface.php',
    'ElementorDeps\\DI\\Factory\\RequestedEntry' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Factory/RequestedEntry.php',
    'ElementorDeps\\DI\\Invoker\\DefinitionParameterResolver' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Invoker/DefinitionParameterResolver.php',
    'ElementorDeps\\DI\\Invoker\\FactoryParameterResolver' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Invoker/FactoryParameterResolver.php',
    'ElementorDeps\\DI\\NotFoundException' => $baseDir . '/vendor_prefixed/php-di/php-di/src/NotFoundException.php',
    'ElementorDeps\\DI\\Proxy\\ProxyFactory' => $baseDir . '/vendor_prefixed/php-di/php-di/src/Proxy/ProxyFactory.php',
    'ElementorDeps\\Invoker\\CallableResolver' => $baseDir . '/vendor_prefixed/php-di/invoker/src/CallableResolver.php',
    'ElementorDeps\\Invoker\\Exception\\InvocationException' => $baseDir . '/vendor_prefixed/php-di/invoker/src/Exception/InvocationException.php',
    'ElementorDeps\\Invoker\\Exception\\NotCallableException' => $baseDir . '/vendor_prefixed/php-di/invoker/src/Exception/NotCallableException.php',
    'ElementorDeps\\Invoker\\Exception\\NotEnoughParametersException' => $baseDir . '/vendor_prefixed/php-di/invoker/src/Exception/NotEnoughParametersException.php',
    'ElementorDeps\\Invoker\\Invoker' => $baseDir . '/vendor_prefixed/php-di/invoker/src/Invoker.php',
    'ElementorDeps\\Invoker\\InvokerInterface' => $baseDir . '/vendor_prefixed/php-di/invoker/src/InvokerInterface.php',
    'ElementorDeps\\Invoker\\ParameterResolver\\AssociativeArrayResolver' => $baseDir . '/vendor_prefixed/php-di/invoker/src/ParameterResolver/AssociativeArrayResolver.php',
    'ElementorDeps\\Invoker\\ParameterResolver\\Container\\ParameterNameContainerResolver' => $baseDir . '/vendor_prefixed/php-di/invoker/src/ParameterResolver/Container/ParameterNameContainerResolver.php',
    'ElementorDeps\\Invoker\\ParameterResolver\\Container\\TypeHintContainerResolver' => $baseDir . '/vendor_prefixed/php-di/invoker/src/ParameterResolver/Container/TypeHintContainerResolver.php',
    'ElementorDeps\\Invoker\\ParameterResolver\\DefaultValueResolver' => $baseDir . '/vendor_prefixed/php-di/invoker/src/ParameterResolver/DefaultValueResolver.php',
    'ElementorDeps\\Invoker\\ParameterResolver\\NumericArrayResolver' => $baseDir . '/vendor_prefixed/php-di/invoker/src/ParameterResolver/NumericArrayResolver.php',
    'ElementorDeps\\Invoker\\ParameterResolver\\ParameterResolver' => $baseDir . '/vendor_prefixed/php-di/invoker/src/ParameterResolver/ParameterResolver.php',
    'ElementorDeps\\Invoker\\ParameterResolver\\ResolverChain' => $baseDir . '/vendor_prefixed/php-di/invoker/src/ParameterResolver/ResolverChain.php',
    'ElementorDeps\\Invoker\\ParameterResolver\\TypeHintResolver' => $baseDir . '/vendor_prefixed/php-di/invoker/src/ParameterResolver/TypeHintResolver.php',
    'ElementorDeps\\Invoker\\Reflection\\CallableReflection' => $baseDir . '/vendor_prefixed/php-di/invoker/src/Reflection/CallableReflection.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Contracts\\Serializable' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Contracts/Serializable.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Contracts\\Signer' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Contracts/Signer.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Exceptions\\InvalidSignatureException' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Exceptions/InvalidSignatureException.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Exceptions\\MissingSecretKeyException' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Exceptions/MissingSecretKeyException.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Exceptions\\PhpVersionNotSupportedException' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Exceptions/PhpVersionNotSupportedException.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\SerializableClosure' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/SerializableClosure.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Serializers\\Native' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Serializers/Native.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Serializers\\Signed' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Serializers/Signed.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Signers\\Hmac' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Signers/Hmac.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Support\\ClosureScope' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Support/ClosureScope.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Support\\ClosureStream' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Support/ClosureStream.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Support\\ReflectionClosure' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Support/ReflectionClosure.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\Support\\SelfReference' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/Support/SelfReference.php',
    'ElementorDeps\\Laravel\\SerializableClosure\\UnsignedSerializableClosure' => $baseDir . '/vendor_prefixed/laravel/serializable-closure/src/UnsignedSerializableClosure.php',
    'ElementorDeps\\PhpDocReader\\AnnotationException' => $baseDir . '/vendor_prefixed/php-di/phpdoc-reader/src/PhpDocReader/AnnotationException.php',
    'ElementorDeps\\PhpDocReader\\PhpDocReader' => $baseDir . '/vendor_prefixed/php-di/phpdoc-reader/src/PhpDocReader/PhpDocReader.php',
    'ElementorDeps\\PhpDocReader\\PhpParser\\TokenParser' => $baseDir . '/vendor_prefixed/php-di/phpdoc-reader/src/PhpDocReader/PhpParser/TokenParser.php',
    'ElementorDeps\\PhpDocReader\\PhpParser\\UseStatementParser' => $baseDir . '/vendor_prefixed/php-di/phpdoc-reader/src/PhpDocReader/PhpParser/UseStatementParser.php',
    'ElementorDeps\\Psr\\Container\\ContainerExceptionInterface' => $baseDir . '/vendor_prefixed/psr/container/src/ContainerExceptionInterface.php',
    'ElementorDeps\\Psr\\Container\\ContainerInterface' => $baseDir . '/vendor_prefixed/psr/container/src/ContainerInterface.php',
    'ElementorDeps\\Psr\\Container\\NotFoundExceptionInterface' => $baseDir . '/vendor_prefixed/psr/container/src/NotFoundExceptionInterface.php',
);
